@@ -6,6 +6,7 @@ import requests
 from sentry.plugins.bases.notify import NotificationPlugin
 
 import sentry_dingding
+import requests
 from .forms import DingDingOptionsForm
 
 DingTalk_API = "https://oapi.dingtalk.com/robot/send?access_token={token}"
@@ -17,7 +18,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.0.12'
+    version = '1.0.14'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
@@ -40,27 +41,24 @@ class DingDingPlugin(NotificationPlugin):
     def notify_users(self, group, event, *args, **kwargs):
         self.post_process(group, event, *args, **kwargs)
 
+    def getGroupCount(self, groupId):
+        url = '/api/0/issues/{groupId}/'.format(groupId =groupId )
+        r = requests.get(url).json()
+        return r["count"]
+
     def post_process(self, group, event, *args, **kwargs):
         """
         Process error.
         """
 
-        print("WB_GROUP", group )
-
-        print("WB_EVENT", event )
-
-
-        for var in args:
-            print ("WB_ARGS",var)
-        
-        print("WB_KWARGS",kwargs)
-
         if not self.is_configured(group.project):
             return
 
         if group.is_ignored():
             return
 
+        count = self.getGroupCount(group.id)
+
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
         title = u'【%s】的项目异常' % event.project.slug
@@ -69,12 +67,12 @@ class DingDingPlugin(NotificationPlugin):
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": u"#### {title} \n\n > {message} \n\n > 设备:{device} \n\n  > UID:{uid} \n\n > {path} \n\n [详细信息]({url})".format(
+                "text": u"#### {title} \n\n > {message} \n\n > 设备:{device} \n\n > 数量:{count} \n\n > UID:{uid} \n\n > {path} \n\n [详细信息]({url})".format(
                     title=title,
                     device=event.get_tag('device'),
                     uid=event.get_tag('uid'),
                     path=event.get_tag('url'),
-                    
+                    count=count,
                     message=event.title or event.message,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                 )
